==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/modules/user/messages/an/auth.php <==
<?php

return [
    '<strong>Password</strong> recovery' => 'Cambiar <strong>clau</strong>',
    '<strong>Please</strong> sign in' => '<strong>Per favor</strong> inicia sesión',
    'Account' => ' Cuenta',
    'Back' => 'Tornar',
    'Confirm' => 'Confirmar',
    'Create account' => 'Creyar cuenta ',
    'Enter security code above' => 'Mete o codigo de seguranza aquí',
    'Forgot your password?' => 'Has ixuplidau a tuya clau?',
    'If you\'re already a member, please login with your username/email and password.' => 'Si ya yes miembro, per favor inicia sesión con o tuyo nombre d\'usuario/correu-e y clau.',
    'Just enter your e-mail address. We\'ll send you recovery instructions!' => 'Simplement mete a tuya adreza de correu-e. Te ninviaremos as instruccions pa recuperar a clau!',
    'Login' => 'Iniciar sesión',
    'Password' => 'clau',
    'Password recovery' => 'Restablir clau',
    'Please login with your username/email and password.' => 'Per favor inicia sesión con o tuyo nombre d\'usuario/correu-e y clau.',
    'Register' => 'Rechistrar-se',
    'Remember me' => 'Recordar-me',
    'Reset password' => 'Restablir clau',
    'Sign in' => 'Iniciar sesión',
    'Username or Email' => 'nombre d\'usuario u correu-e',
    'Your email' => 'O tuyo correu-e',
    'Your password' => ' A tuya clau',
    'Your password has been successfully changed!' => 'A tuya clau s\'ha cambiau correctament!',
    'Your password is incorrect!' => ' ',
    '<strong>Account</strong> registration' => '',
    '<strong>Change</strong> Password' => '',
    '<strong>Change</strong> your password' => '',
    '<strong>Join</strong> the network' => '',
    '<strong>Password</strong> changed!' => '',
    '<strong>Password</strong> recovery!' => '',
    '<strong>Registration</strong> successful!' => '',
    '<strong>Sign</strong> up' => '',
    '<strong>Your account</strong> has been successfully created!' => '',
    'After activating your account by the administrator, you will receive a notification by email.' => '',
    'Change password' => '',
    'Create Account' => '',
    'Don\'t have an account? Join the network by entering your e-mail address.' => '',
    'Due to security reasons you are required to change your password in order to access the platform.' => '',
    'Go to login page' => '',
    'Group' => '',
    'Hello {displayName}' => '',
    'Hello {displayName},' => '',
    'If a user account associated with this email address exists, further instructions will be sent to you by email shortly.' => '',
    'If you don\'t use this link within 24 hours, it will expire.' => '',
    'Log out' => '',
    'New user needs approval' => '',
    'Password reset' => '',
    'Please check your email and follow the instructions!' => '',
    'Please click on the link below to view request:' => '',
    'Please enter the letters from the image.' => '',
    'Please use the following link within the next day to reset your password.' => '',
    'Please wait' => '',
    'Registration successful' => '',
    'Reset Password' => '',
    'To log in with your new account, click the button below.' => '',
    'User or Password incorrect.' => '',
    'a new user {displayName} needs approval.' => '',
    'back to home' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/user/messages/an/auth.php <==
<?php

return [
    '<strong>Password</strong> recovery' => 'Cambiar <strong>clau</strong>',
    '<strong>Please</strong> sign in' => '<strong>Per favor</strong> inicia sesión',
    'Account' => ' Cuenta',
    'Back' => 'Tornar',
    'Confirm' => 'Confirmar',
    'Create account' => 'Creyar cuenta ',
    'Forgot your password?' => 'Has ixuplidau a tuya clau?',
    'If you\'re already a member, please login with your username/email and password.' => 'Si ya yes miembro, per favor inicia sesión con o tuyo nombre d\'usuario/correu-e y clau.',
    'Just enter your e-mail address. We\'ll send you recovery instructions!' => 'Simplement mete a tuya adreza de correu-e. Te ninviaremos as instruccions pa recuperar a clau!',
    'Login' => 'Iniciar sesión',
    'Password' => 'clau',
    'Password recovery' => 'Restablir clau',
    'Please login with your username/email and password.' => 'Per favor inicia sesión con o tuyo nombre d\'usuario/correu-e y clau.',
    'Register' => 'Rechistrar-se',
    'Remember me' => 'Recordar-me',
    'Reset password' => 'Restablir clau',
    'Sign in' => 'Iniciar sesión',
    'Username or Email' => 'nombre d\'usuario u correu-e',
    'Your email' => 'O tuyo correu-e',
    'Your password' => ' A tuya clau',
    'Your password has been successfully changed!' => 'A tuya clau s\'ha cambiau correctament!',
    'Your password is incorrect!' => ' ',
    '<strong>Account</strong> registration' => '',
    '<strong>Change</strong> Password' => '',
    '<strong>Change</strong> your password' => '',
    '<strong>Join</strong> the network' => '',
    '<strong>Password</strong> changed!' => '',
    '<strong>Password</strong> recovery!' => '',
    '<strong>Registration</strong> successful!' => '',
    '<strong>Sign</strong> up' => '',
    '<strong>Your account</strong> has been successfully created!' => '',
    'After activating your account by the administrator, you will receive a notification by email.' => '',
    'Almost there!' => '',
    'An email has been sent to {emailAddress}. Please check your inbox to complete the registration.' => '',
    'Change password' => '',
    'Create Account' => '',
    'Don\'t have an account? Join the network by entering your e-mail address.' => '',
    'Due to security reasons you are required to change your password in order to access the platform.' => '',
    'Go to login page' => '',
    'Group' => '',
    'Hello {displayName}' => '',
    'Hello {displayName},' => '',
    'If a user account associated with this email address exists, further instructions will be sent to you by email shortly.' => '',
    'If you don\'t see the email, please check your spam folder.' => '',
    'If you don\'t use this link within 24 hours, it will expire.' => '',
    'Log out' => '',
    'New user needs approval' => '',
    'Password reset' => '',
    'Please click on the link below to view request:' => '',
    'Please use the following link within the next day to reset your password.' => '',
    'Please wait' => '',
    'Reset Password' => '',
    'To log in with your new account, click the button below.' => '',
    'User or Password incorrect.' => '',
    'a new user {displayName} needs approval.' => '',
];
